# How to generate a PIP package?
- Change setup.cfg version
- py -m build
- py -m twine upload --skip-existing dist/*

Use this api key: pypi-AgEIcHlwaS5vcmcCJGI3N2ViYWQ2LTE4MGMtNDA3OC1iMGY5LTZmNjQ1NjliZDI2OAACFlsxLFsic2NyYXBlYW55dGhpbmciXV0AAixbMixbIjU3MTA5MDEwLTdmYTEtNGMzNi1hZGVhLTg1NGZiYmI0OWYwMyJdXQAABiDxnRg3tsxVoJokoT7DeOr4uMalqIGnY-u2NU3vLzSukw

Reference: https://packaging.python.org/en/latest/tutorials/packaging-projects/